@@ -25,18 +25,23 @@ KSSL_VG_model <- function(VG_params, phi_min=10^-6, phi_max=10^8, pts=100) {
   
   # Rosetta units for alpha and npar are cm and 1/cm
   # convert kPa to cm of H20
-  m$h <- m$phi * 10.19716
+  h <- m$phi * 10.19716
   
   # compute theta given measured parameters and sequence of phi
-  m$theta <- .vg(phi= m$h, theta_r = VG_params$theta_r, theta_s = VG_params$theta_s, alpha = 10^(VG_params$alpha), n = 10^(VG_params$npar))
+  m$theta <- .vg(phi= h, theta_r = VG_params$theta_r, theta_s = VG_params$theta_s, alpha = 10^(VG_params$alpha), n = 10^(VG_params$npar))
   
-  # use splines to fit inverse model
+  # use splines to fit standard model: phi -> theta
+  # scale of theta {0,1}
+  # phi: units of kPa
+  vg.fwd <- splinefun(m$phi, m$theta)
+  
+  # use splines to fit inverse model: theta -> phi
   # scale of theta {0,1}
   # phi: units of kPa
   vg.inv <- splinefun(m$theta, m$phi)
   
   # return curve and spline function
-  return(list(VG_curve=m, VG_inverse_function=vg.inv))
+  return(list(VG_curve=m, VG_function=vg.fwd, VG_inverse_function=vg.inv))
 }
 
 
