@@ -6,7 +6,7 @@ test_that("fetchSCAN() works", {
   
   # hack for in-house testing only
   # WWW services aren't always available and will cause CRAN to drop our package if tests fail
-  if(! soilDB:::.local_NASIS_defined()) {
+  if( ! getOption('.soilDB_testNetworkFunctions') )  {
     skip("in-house testing only")
   }
   
@@ -24,7 +24,7 @@ test_that("fetchSCAN() returns the right kind of data", {
   
   # hack for in-house testing only
   # WWW services aren't always available and will cause CRAN to drop our package if tests fail
-  if(! soilDB:::.local_NASIS_defined()) {
+  if( ! getOption('.soilDB_testNetworkFunctions') )  {
     skip("in-house testing only")
   }
   
