@@ -7,7 +7,7 @@ test_that("siblings() returns reasonable data", {
   
   # hack for in-house testing only
   # WWW services aren't always available and will cause CRAN to drop our package if tests fail
-  if(! soilDB:::.local_NASIS_defined()) {
+  if( ! getOption('.soilDB_testNetworkFunctions') ) {
     skip("in-house testing only")
   }
   
@@ -31,7 +31,7 @@ test_that("siblings() returns skeleton with bogus query", {
   
   # hack for in-house testing only
   # WWW services aren't always available and will cause CRAN to drop our package if tests fail
-  if(! soilDB:::.local_NASIS_defined()) {
+  if( ! getOption('.soilDB_testNetworkFunctions') ) {
     skip("in-house testing only")
   }
   
